## cdf 

### Improved

- Warning on YAML syntax errors when running `cdf build` for resources
types hosted extractor mapping and destinations, as well as streamlit
applications.

## templates

No changes.